Index: include/gpu/GrContext.h |
diff --git a/include/gpu/GrContext.h b/include/gpu/GrContext.h |
index 6d89d4668a967780961947d9d557444b34dd721f..2b3b8143974d234e5b30b13866983e1a2775cda4 100644 |
--- a/include/gpu/GrContext.h |
+++ b/include/gpu/GrContext.h |
@@ -630,53 +630,8 @@ public: |
uint32_t pixelOpsFlags = 0); |
/** |
- * Copy the src pixels [buffer, row bytes, pixel config] into a render target at the specified |
- * rectangle. |
- * @param target the render target to write into. NULL means the current render target. |
- * @param left left edge of the rectangle to write (inclusive) |
- * @param top top edge of the rectangle to write (inclusive) |
- * @param width width of rectangle to write in pixels. |
- * @param height height of rectangle to write in pixels. |
- * @param config the pixel config of the source buffer |
- * @param buffer memory to read the rectangle from. |
- * @param rowBytes number of bytes between consecutive rows. Zero means rows are tightly |
- * packed. |
- * @param pixelOpsFlags see PixelOpsFlags enum above. |
- * |
- * @return true if the write succeeded, false if not. The write can fail because of an |
- * unsupported combination of target and pixel configs. |
- */ |
- bool writeRenderTargetPixels(GrRenderTarget* target, |
- int left, int top, int width, int height, |
- GrPixelConfig config, const void* buffer, |
- size_t rowBytes = 0, |
- uint32_t pixelOpsFlags = 0); |
- |
- /** |
- * Reads a rectangle of pixels from a texture. |
- * @param texture the texture to read from. |
- * @param left left edge of the rectangle to read (inclusive) |
- * @param top top edge of the rectangle to read (inclusive) |
- * @param width width of rectangle to read in pixels. |
- * @param height height of rectangle to read in pixels. |
- * @param config the pixel config of the destination buffer |
- * @param buffer memory to read the rectangle into. |
- * @param rowBytes number of bytes between consecutive rows. Zero means rows are tightly |
- * packed. |
- * @param pixelOpsFlags see PixelOpsFlags enum above. |
- * |
- * @return true if the read succeeded, false if not. The read can fail because of an unsupported |
- * pixel config. |
- */ |
- bool readTexturePixels(GrTexture* texture, |
- int left, int top, int width, int height, |
- GrPixelConfig config, void* buffer, |
- size_t rowBytes = 0, |
- uint32_t pixelOpsFlags = 0); |
- |
- /** |
- * Writes a rectangle of pixels to a texture. |
- * @param texture the render target to read from. |
+ * Writes a rectangle of pixels to a surface. |
+ * @param surface the surface to write to. |
* @param left left edge of the rectangle to write (inclusive) |
* @param top top edge of the rectangle to write (inclusive) |
* @param width width of rectangle to write in pixels. |
@@ -687,9 +642,9 @@ public: |
* means rows are tightly packed. |
* @param pixelOpsFlags see PixelOpsFlags enum above. |
* @return true if the write succeeded, false if not. The write can fail because of an |
* unsupported combination of texture and pixel configs. |
*/ |
- bool writeTexturePixels(GrTexture* texture, |
+ bool writeSurfacePixels(GrSurface* surface, |
int left, int top, int width, int height, |
GrPixelConfig config, const void* buffer, |
size_t rowBytes, |
@@ -687,9 +642,9 @@ public: |
* @param pixelOpsFlags see PixelOpsFlags enum above. |
* @return true if the write succeeded, false if not. The write can fail because of an |
- * unsupported combination of texture and pixel configs. |
+ * unsupported combination of surface and src configs. |
*/ |